[![GitHub Repo stars](https://img.shields.io/github/stars/Bezdarnost/claritycore?style=social)](https://github.com/hiyouga/Bezdarnost/claritycore)
[![Downloads](https://static.pepy.tech/badge/claritycore)](https://pepy.tech/project/claritycore)
[![License Apache 2.0](https://badgen.net/badge/license/apache2.0/blue)](https://github.com/Bezdarnost/claritycore/blob/master/LICENSE)
[![PyPI version](https://badge.fury.io/py/claritycore.svg)](https://pypi.org/project/claritycore/)
<img alt="Python 3.10+" src="https://img.shields.io/badge/python-3.10+-blue">
<a href="hhttps://discord.gg/Zw2kFTruD5"><img alt="Discord" src="https://img.shields.io/discord/1426554369750470658?color=7289da&logo=discord&logoColor=white"></a>

<p align="center">
  <picture>
    <source media="(prefers-color-scheme: dark)" srcset="https://raw.githubusercontent.com/Bezdarnost/claritycore/main/docs/assets/logo_full.png">
    <img alt="ClarityCore" src="https://raw.githubusercontent.com/Bezdarnost/claritycore/main/docs/assets/logo_full.png" width=100%>
  </picture>
</p>

<h3 align="center">
Easy and fast low-level vision for everyone
</h3>

---

Next-generation Open Source toolkit for low-level vision. Engineered for state-of-the-art performance in image and video pixel2pixel tasks, including Super-Resolution, Denoising, Deblurring, and more.

<div align="center">
  
If you find ClarityCore useful, please consider giving it a star ⭐ and **[Join Discord](https://discord.gg/Zw2kFTruD5)** !

</div>

---

*Latest News* 🚀
- [2025/10] Project start

---

Quickstart (uv)
---------------

1. Ensure you have Python 3.10+ installed.
2. Install `uv` (one-time):

```
curl -LsSf https://astral.sh/uv/install.sh | sh
```

3. Install the project in editable mode with uv:

```
uv pip install -e .
```

4. Run the sample entry point:

```
uv run python -m claritycore
```

Project Status
--------------

This project is in its early stage. APIs and structure will evolve rapidly.

Citation
--------

If you use ClarityCore in your research, please cite:

```
@software{ClarityCore_2025,
          author = {Urumbekov, Aman},
          license = {Apache-2.0},
          month = sep,
          title = {{ClarityCore}},
          url = {https://github.com/Bezdarnost/claritycore},
          year = {2025}
}
```

Urumbekov, A. (2025). ClarityCore: A toolkit for low-level vision. GitHub. https://github.com/bezdarnost/claritycore

## Star History

[![Star History Chart](https://api.star-history.com/svg?repos=bezdarnost/claritycore&type=Date)](https://www.star-history.com/#bezdarnost/claritycore&Date)

License
-------

Apache License 2.0. See `LICENSE`.
